%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Trevor Mamer
% Last update: 4/19/2019
% Description: 
%   Using the LabVIEW companion application, this matlab script
%   was meant to plot the output from five captures combined for 
%   comparision plotting. The original use case was capacitance
%   over strain plots, the original application involving a 50% strain
%   range.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc; clear; close all; %clear all workspace before running
load('etpu_capOverTime_matlabformatted.mat');   %load file
% preliminary setup
M1 = size(LRC1,1);
N1 = 0;
bottom = 1*10^-11; top = 15*10^-11; % necessary for adjusting the plot limits later on

% begin setting initial arrays
cv1 = zeros(size(LRC1,1)/3,1);  % fill capacitance array value with zeros
cv1(1:end) = LRC1(2:3:end,1);   % fill zero array with actual values
cv1(1786:end) = []; % cut off values after this point, set all arrays 
strain1 = zeros(size(cv1,1),1); % create strain array for x axis
strain1(1:end) = (50/size(cv1,1):50/size(cv1,1):50); % strain was at a constant rate

cv2 = zeros(size(LRC2,1)/3,1);
cv2(1:end) = LRC2(2:3:end,1);
cv2(1786:end) = [];

cv3 = zeros(size(LRC3,1)/3,1);
cv3(1:end) = LRC3(2:3:end,1);
cv3(1786:end) = [];

cv4 = zeros(size(LRC4,1)/3,1);
cv4(1:end) = LRC4(2:3:end,1);
cv4(1786:end) = [];

cv5 = zeros(size(LRC5,1)/3,1);
cv5(1:end) = LRC5(2:3:end,1);
cv5(1786:end) = [];

cvult = (cv1+cv2+cv3+cv4+cv5) / 5; % take average for average plot

% create figure and begin plotting initial values
figure;
plot(strain1,cv1,'b.'); hold on
plot(strain1,cv2,'g.'); 
plot(strain1,cv3,'k.');
plot(strain1,cv4,'c.'); 
plot(strain1,cv5,'r.'); 

ylim([bottom, top]);
grid on;
ylabel('Capacitance (F)');
xlabel('Strain Percentage (%)');
legend('Sample 1','Sample 2','Sample 3','Sample 4','Sample 5');
title('PE873 Stretch Test - Capacitance over Strain'); hold off;

figure;
plot(strain1,cvult,'r.');hold on
ylim([bottom, top]);
grid on;
ylabel('Capacitance (F)');
xlabel('Strain Percentage (%)');
legend('Average');
title('PE873 Stretch Test - Capacitance over Strain - Averaged');
hold off;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Find dropped values (values below zero and above maximum threshold)
dv1 = find(abs(cv1)>1.5e-10); dv1 = [dv1;find(cv1<0)];
dv2 = find(abs(cv2)>1.5e-10); dv2 = [dv2;find(cv2<0)];
dv3 = find(abs(cv3)>1.5e-10); dv3 = [dv3;find(cv3<0)];
dv4 = find(abs(cv4)>1.5e-10); dv4 = [dv4;find(cv4<0)];
dv5 = find(abs(cv5)>1.5e-10); dv5 = [dv5;find(cv5<0)];

% set dropped values to NaN for plotting
cv1(dv1) = [NaN];
cv2(dv2) = [NaN];
cv3(dv3) = [NaN];
cv4(dv4) = [NaN];
cv5(dv5) = [NaN];

figure;
plot(strain1,cv1,'b.'); hold on
plot(strain1,cv2,'g.'); 
plot(strain1,cv3,'k.');
plot(strain1,cv4,'c.'); 
plot(strain1,cv5,'r.'); 
% ylim([bottom, top]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% remove dropped values for polyfit
cv1(dv1) = []; cv2(dv2) = []; cv3(dv3) = []; cv4(dv4) = []; cv5(dv5) = [];
strain0 = strain1; strain0(dv1) = [];
strain2 = strain1; strain2(dv2) = [];
strain3 = strain1; strain3(dv3) = [];
strain4 = strain1; strain4(dv4) = [];
strain5 = strain1; strain5(dv5) = [];

% run polyfit, find y fit line for all 5 arrays
p1 = polyfit(strain0,cv1,1)
yfit1 = polyval(p1,strain0);
yresid1 = cv1 - yfit1;
ssresid1 = sum(yresid1.^2)
sstotal1 = (length(cv1)-1)* var(cv1)
rsq1 = 1 - ssresid1/sstotal1
rsq_adj1 = 1 -ssresid1/sstotal1 *(length(cv1)-1)/(length(cv1)-length(p1))

p2 = polyfit(strain2,cv2,1)
yfit2 = polyval(p2,strain2);
yresid2 = cv2 - yfit2;
ssresid2 = sum(yresid2.^2)
sstotal2 = (length(cv2)-1)* var(cv2)
rsq2 = 1 - ssresid2/sstotal2
rsq_adj2 = 1 -ssresid2/sstotal2 *(length(cv2)-1)/(length(cv2)-length(p2))

p3 = polyfit(strain3,cv3,1)
yfit3 = polyval(p3,strain3);
yresid3 = cv3 - yfit3;
ssresid3 = sum(yresid3.^2)
sstotal3 = (length(cv3)-1)* var(cv3)
rsq3 = 1 - ssresid3/sstotal3
rsq_adj3 = 1 -ssresid3/sstotal3 *(length(cv3)-1)/(length(cv3)-length(p3))

p4 = polyfit(strain4,cv4,1)
yfit4 = polyval(p4,strain4);
yresid4 = cv4 - yfit4;
ssresid4 = sum(yresid4.^2)
sstotal4 = (length(cv4)-1)* var(cv4)
rsq4 = 1 - ssresid4/sstotal4
rsq_adj4 = 1 -ssresid4/sstotal4 *(length(cv4)-1)/(length(cv4)-length(p4))

p5 = polyfit(strain5,cv5,1)
yfit5 = polyval(p5,strain5);
yresid5 = cv5 - yfit5;
ssresid5 = sum(yresid5.^2)
sstotal5 = (length(cv5)-1)* var(cv5)
rsq5 = 1 - ssresid5/sstotal5
rsq_adj5 = 1 -ssresid5/sstotal5 *(length(cv5)-1)/(length(cv5)-length(p5))

% plot all data
plot(strain0,yfit1,'r--')
plot(strain2,yfit2,'k--')
plot(strain3,yfit3,'c--')
plot(strain4,yfit4,'k-')
plot(strain5,yfit5,'g--')

a = ['S1 r^2 = ' num2str(rsq1)];
b = ['S2 r^2 = ' num2str(rsq2)];
c = ['S3 r^2 = ' num2str(rsq3)];
d = ['S4 r^2 = ' num2str(rsq4)];
e = ['S5 r^2 = ' num2str(rsq5)];

ylabel('Capacitance (F)');
xlabel('Strain Percentage (%)');
grid on;
legend('Sample 1','Sample 2','Sample 3','Sample 4','Sample 5',...
    a,b,c,d,e);
title('ETPU Stretch Test - Capacitance over Strain'); hold off;
